@@ -26,6 +26,8 @@ use vars qw( %format_aliases );
 		   'texinfo'	=> 'Texinfo',
 		   'text'	=> 'Text',
 		   'textov'	=> 'TextOV',
+		   'xml'	=> 'XML',
+		   'sgml'	=> 'SGML',
 		   );
 
 ## ----------------------------------------------------------------------
