@@ -29,8 +29,8 @@ use SGMLS::Output;
 
 ## ----------------------------------------------------------------------
 ## get command line options
-use vars qw( $opt_L $opt_b $opt_c $opt_e $opt_f $opt_l $opt_m $opt_t $opt_1 );
-getopts( 'Lb:ce:f:l:mt:1' );
+use vars qw( $opt_L $opt_P $opt_b $opt_c $opt_e $opt_f $opt_l $opt_m $opt_t $opt_1 $opt_x );
+getopts( 'LPb:ce:f:l:mt:1x' );
 
 ## ----------------------------------------------------------------------
 ## get format, map and locale
@@ -309,6 +309,7 @@ sub start_sect
 }
 sub end_sect
 {
+    &{$Format."::"._output_sect}();
 }
 
 ## ----------------------------------------------------------------------
@@ -319,6 +320,7 @@ sub start_sect1
 }
 sub end_sect1
 {
+    &{$Format."::"._output_sect1}();
 }
 
 ## ----------------------------------------------------------------------
@@ -329,6 +331,7 @@ sub start_sect2
 }
 sub end_sect2
 {
+    &{$Format."::"._output_sect2}();
 }
 
 ## ----------------------------------------------------------------------
@@ -339,6 +342,7 @@ sub start_sect3
 }
 sub end_sect3
 {
+    &{$Format."::"._output_sect3}();
 }
 
 ## ----------------------------------------------------------------------
@@ -349,6 +353,7 @@ sub start_sect4
 }
 sub end_sect4
 {
+    &{$Format."::"._output_sect4}();
 }
 
 ## ----------------------------------------------------------------------
