@@ -476,20 +476,38 @@ sub _output_toc
 	my $toc_entry_level = $toc_entry_level{ $toc_entry_id };
 	if ( $toc_level > $toc_entry_level )
 	{
-	    output( "</ul></li>\n" x ( $toc_level - $ toc_entry_level) );
+            output( "\n" );
+	    while ( $toc_level > $toc_entry_level )
+	    {
+		output( "  " x ( $toc_level + 1 ) );
+		output( "</ul></li>\n" );
+	        $toc_level += -1 ;
+	    }
 	}
 	elsif ( $toc_level < $toc_entry_level )
 	{
-	    output( "<li><ul>\n" x ( $toc_entry_level - $toc_level ) );
+            output( "\n" );
+	    output( "  " x ( $toc_entry_level + 1 ) );
+	    output( "<ul>\n" x ( $toc_entry_level - $toc_level ) );
 	}
+	elsif ( $toc_level > -1 )
+	{
+	    output( "</li>\n" );
+	}
+	output( "  " x ( $toc_entry_level + 1 ) );
 	output( "<li>" );
 	_output_ref( "$toc_entry_id $toc_entry_name{ $toc_entry_id }", '',
 		     $toc_entry_chapter_id{ $toc_entry_id },
 		     $toc_entry_fragment{ $toc_entry_id } );
-	output( "</li>\n" );
 	$toc_level = $toc_entry_level;
     }
-    output( "</ul></li>\n" x ( $toc_level + 1 ) );
+    output( "</li>\n" );
+    while ( $toc_level > -1 )
+    {
+	output( "  " x ( $toc_level + 1 ) );
+	output( "</ul></li>\n" );
+        $toc_level += -1 ;
+    }
     output( "</ul>\n" );
     $toc = pop_output;
 }
